BlocksNet
=========

.. include:: ../../README.rst
   :start-after: .. logo-start
   :end-before: .. logo-end

.. include:: ../../README.rst
   :start-after: .. description-start
   :end-before: .. description-end

Documentation:
--------------

.. toctree::
   :maxdepth: 2

   blocksnet/index
   examples/index
   api/index
   about_us

Features:
---------

.. include:: ../../README.rst
   :start-after: .. features-start
   :end-before: .. features-end

Acknowledgements
----------------

.. include:: ../../README.rst
   :start-after: .. acknowledgments-start
   :end-before: .. acknowledgments-end
